<?php

require_once 'base/FpaassoceventoEntityBase.php';


/**
 * FpaassoceventoEntity.
 *
 * @package Entity
 * @author  alessandrobartels
 */
class FpaassoceventoEntity extends FpaAssoceventoEntityBase
{
    private $_nrOrgPadrao;

    /**
     * Construtor.
     *
     * @param integer $id    Identificador.
     * @param integer $nrorg Numero da Organizacao.
     *
     * @author alessandrobartels - 11/07/2011
     */
    public function __construct($id = null, $nrorg = null, $nrOrgPadrao = null){
        parent::__construct($id);
        $this->_nrOrgPadrao = $nrOrgPadrao;
        $this->setNrorg($nrorg);
    }


    /**
     * Inicializa lista de Associacao de Eventos - (add o nr do tipo assoc e nao a instancia como nos demais casos).
     *
     * @param integer $nrorg Numero da Organizacao.
     *
     * @return void
     *
     * @author alessandrobartels
     */
    public function inicializaLista($nrorg){
        $tmp = Fpaassocevento::retornaAssocEvento($nrorg,$this->_nrOrgPadrao);

        foreach ($tmp as $tmp_associacao) {
            $this->addItem($tmp_associacao->getNreventom(), $tmp_associacao->getNrtipoassoceve());

        }
    }


    /**
     * Retorna instancia da associacao parametrizada.
     *
     * @param integer $tipo_associacao Numero do tipo de associacao.
     * @param integer $nrorg           Numero da Organizacao.
     *
     * @throws Exception Associacao nao encontrada.
     * @return integer
     *
     * @author alessandrobartels
     */
    public function retornaEvento($tipo_associacao, $nrorg){
        $itens = $this->getItems();
        if (empty($itens) === true) {
            $this->inicializaLista($nrorg);
        }

        $item = $this->getItem($tipo_associacao);
        if (empty($item) === false) {
            return $item;
        }

        //@todo MsgCalculo
        MsgCalculo::getInstance()->adicionaMensagem('Associacao '.$tipo_associacao.' nao encontrada');
        /* throw new Exception('Associacao '.$tipo_associacao.' nao encontrada'); */
        //tk_warning('Associacao '.$tipo_associacao.' nao encontrada');

    }


    /**
     * Retorna instancia da entidade FpaeventomEntity conforme parametrizacao do tipo de associacao do evento.
     *
     * @param integer          $associacao Numero da Associacao de eventos.
     * @param FpaeventomEntity $eventom    Instancia da classe FpaeventomEntity.
     * @param integer          $nrOrg      Numero da Organizacao.
     *
     * @return FpaeventomEntity
     *
     * @author alessandrobartels
     */
    public function retornaEventoAssociado($associacao, FpaeventomEntity $eventom, $nrOrg){
        $nrevento = $this->retornaEvento($associacao, $nrOrg);
        return $eventom->retornaEvento($nrevento);
       // Funcao retornaEvento do evento deve passar o nrorg.
    }



     public function determinaReferenciaEventoAssociado(array $nrAssociacoes, $eventom){
         $eventoAssoc = array();
         foreach ($nrAssociacoes as $nrAssocEvento){
             $evento = $this->retornaEventoAssociado($nrAssocEvento, $eventom, $this->getNrorg());
             // testa se o objeto é inválido Borba 20/02/2013
             if (is_object($evento)){
                $eventoAssoc[$nrAssocEvento] = (int)$evento->historico->getVrpercentualevento();
             }
             else {
                //@todo MsgCalculo
                MsgCalculo::getInstance()->adicionaMensagem('Evento não encontrado para associação '.$nrAssocEvento);
                //tk_warning('Evento não encontrado para associação '.$nrAssocEvento);
             }
         }

         return $eventoAssoc;
     }

}

