<?php

/**
 * GepReuniaoLogic.
 *
 * @package Logic
 * @author  samuelleite
 */
class GepReuniaoLogic{


    private $_GerSalaEntity;
    private $_GepPautapadraoEntity;


    public function __construct(){
        $this->_GerSalaEntity = new GerSalaEntity();
        $this->_GepPautapadraoEntity = new GepPautapadraoEntity();
    }


    /**
     * Consulta situacao da sala para um determinado periodo de datas
     *
     * @param integer $nrsala    Numero da Sala.
     * @param string  $dataIni   Data de Inicio.
     * @param string  $dataFim   Data de Fim.
     * @param integer $nrorg     Numero da Organizacao.
     * @param integer $nrreuniao Numero da reuniao.
     *
     * @return Ambigous <<type>, multitype:, mixed>|boolean
     */
    public static function consultaDadosByPeriodoDeDatas($nrsala, $dataIni, $dataFim, $nrorg, $nrreuniao){
        $situacaoSala = GepReuniaoEntity::consultaDadosByPeriodoDeDatas(
            $nrsala, $dataIni, $dataFim, $nrorg, $nrreuniao
        );
        return $situacaoSala;
    }


    /**
     * Consulta dados de uma reuniao.
     *
     * @param integer $nrreuniao Numero da Sala.
     * @param integer $nrorg     Numero da Organizacao.
     *
     * @return Ambigous <<type>, multitype:, mixed>|boolean
     */
    public static function consultaDadosReuniao($nrreuniao, $nrorg){
        $dados = GepReuniaoEntity::consultaDadosReuniao($nrreuniao, $nrorg);
        return $dados;
    }


    /**
     * Gera novo codigo de reuniao.
     *
     * @param integer $nrorg Numero da organizao.
     *
     * @return Ambigous <$codigo, number, number, string>
     */
    public static function novoCodigoGepReuniao($nrorg){
        $codigo = GepReuniaoEntity::retornaProxNumeroReuniao($nrorg);
        return $codigo;
    }


    /**
     * Metodo para inserir as pautas padroes.
     *
     * @param integer $tipoReuniao Tipo de reuniao.
     * @param integer $nrreuniao   Numero da reuniao.
     * @param integer $nrorg       Numero da organizacao.
     * @param string  $data        Data atual.
     * @param integer $operador    Operador.
     *
     * @return void
     */
    public static function inserePautasPadroes($tipoReuniao, $nrreuniao, $nrorg, $data, $operador){
        $dados_pautapadrao = GepPautapadraoEntity::consultaDadosPautaPadrao($tipoReuniao, $nrorg);
        if ($dados_pautapadrao !== false) {
            foreach ($dados_pautapadrao as $dados) {
                $nrpautareuniao = GepPautareuniaoEntity::retornaProxNumeroPautareuniao($nrorg);
                $insere = GepPautareuniaoEntity::incluiPauta(
                    $nrpautareuniao, $nrorg, $nrreuniao, $dados->getNrordenapauta(), $dados->getDsgrupopauta(),
                    $dados->getDstitulopauta(), $dados->getTxpauta(), $dados->getDsobservpauta(), $data, $operador,
                    $nrorg, $data, $operador, $nrorg
                );
            }
        }
    }


    /**
     * Metodo para verificar a sala.
     *
     * @param integer $nrorg    Codigo da organizacao.
     * @param integer $sala     Numero da sala.
     * @param string  $dtinicio Data de inicio.
     * @param string  $dtfim    Data de fim.
     *
     * @return multitype:number string Ambigous <qtmaximapessoas, NULL>
     */
    public function validaSala($nrorg, $sala, $dtinicio, $dtfim) {
        $qt_convocados = GepConvocadoreuniaoEntity::consultaTotalConvocadosSalaPorPeriodo($nrorg, $sala, $dtinicio, $dtfim);

        $dados_sala = $this->_GerSalaEntity->consultaDadosSala($nrorg, $sala);
        $capacidade_sala = $dados_sala->getQtmaximapessoas();

        if ($qt_convocados > 0) {
            if ($capacidade_sala > $qt_convocados) {
                $qt_restante = $capacidade_sala - $qt_convocados;
                $permisao_mais_reunioes = null;
            } else {
                $qt_restante = 0;
                $permisao_mais_reunioes = 'N';
            }
        } else {
            $qt_restante = $capacidade_sala;
            $permisao_mais_reunioes = 'S';
        }

        $return = array(
                   'QTRESTANTEPARTICIPANTES' => $qt_restante,
                   'PERMISSAOREUNIAO'        => $permisao_mais_reunioes,
                   'CAPACIDADESALA'          => $capacidade_sala,
                  );

        return $return;
    }


    /**
     * Retorna as reunioes realizadas pelo operador.
     *
     * @param integer $nrorg    Numero da organizacao.
     * @param integer $operador Numero do operador.
     * @param date    $data     Data atual no sistema.
     *
     * @return boolean
     */
    public function retornaReunioesRealizadasByOperador($nrorg,$operador,date $data){
        $resultado = GepReuniaoEntity::retornaReunioesRealizadasByOperador($nrorg, $operador, $data);
        foreach ($resultado as $reunioes) {
            $datainicioreal = $reunioes->getDtiniciorealizado();
            $datafimreal = $reunioes->getDtfimrealizado();
            if (empty($datainicioreal) === true || empty($datafimreal) === true) {
                $ref .= "Reuniao: ".$reunioes->getNrreuniao()."
                - Referencia: ".$reunioes->getDsreferenciareuniao()."
            	- Finalizada em: ".$reunioes->getDtfimplanejado()."<br>";
            } else {
                $nrreuniao = $reunioes->getNrreuniao();
                $pautas = GepPautareuniaoLogic::consultaPautasByReuniao($nrreuniao, $nrorg);
                if (empty($pautas) === false) {
                    foreach ($pautas as $pauta) {
                        $nrpautareuniao = $pauta->getNrpautareuniao();
                        $ata = GepAta::consultaDadosAtaByNrpautareuniao($nrorg, $nrpautareuniao);
                        if (empty($ata) === true) {
                            $ref .= "Reuniao: ".$reunioes->getNrreuniao()."
                            - Referencia: ".$reunioes->getDsreferenciareuniao()."
                        	- Finalizada em: ".$reunioes->getDtfimplanejado()."<br>";
                            continue 2;
                        }
                    }
                } else {
                    $convocados = GepConvocadoreuniaoLogic::consultaConvocadosPorReuniao($nrreuniao, $nrorg);
                    foreach ($convocados as $convocado) {
                        $idpart = $convocado->getIdparticipacao();
                        if ($idpart === 'P') {
                            $ref .= "Reuniao: ".$reunioes->getNrreuniao()."
                            - Referencia: ".$reunioes->getDsreferenciareuniao()."
                        	- Finalizada em: ".$reunioes->getDtfimplanejado()."<br>";
                            continue 2;
                        }
                    }
                }
            }
        }

        return $ref;

    }


    /**
     * Metodo para consultar os valores da tela de reuniao.
     *
     * @return string
     */
    public static function consultaReunioes(){
        $sql = GepReuniaoEntity::consultaReunioes();
        return $sql;
    }


}